@@ -1,26 +1,3 @@
-# $Id: Tinylink.pm 60 2007-04-15 19:05:34Z dave $
-
-=head1 NAME
-
-WWW::Shorten::Tinylink - Perl interface to Tinylink.com
-
-=head1 SYNOPSIS
-
-  use WWW::Shorten 'Tinylink';
-
-  $short_url = makeashorterlink($long_url);
-
-  $long_url  = makealongerlink($short_url);
-  $long_url  = makealongerlink($nickname);
-
-=head1 DESCRIPTION
-
-A Perl interface to the web site Tinylink.com. Tinylink.com simply
-maintains a database of long URLs, each of which has a unique
-identifier.
-
-=cut
-
 package WWW::Shorten::Tinylink;
 
 use 5.006;
@@ -29,22 +6,10 @@ use warnings;
 
 use base qw( WWW::Shorten::generic Exporter );
 our @EXPORT = qw(makeashorterlink makealongerlink);
-our $VERSION = '1.90';
+our $VERSION = "1.84";
 
 use Carp;
 
-=head1 Functions
-
-=head2 makeashorterlink
-
-The function C<makeashorterlink> will call the Tinylink.com web site
-passing it your long URL and will return the shorter (tinylink) version.
-
-Multiple submissions of the same URL will result in different codes
-being returned.
-
-=cut
-
 sub makeashorterlink ($)
 {
     my $url = shift or croak 'No URL passed to makeashorterlink';
@@ -62,16 +27,6 @@ sub makeashorterlink ($)
     return;
 }
 
-=head2 makealongerlink
-
-The function C<makealongerlink> does the reverse. C<makealongerlink>
-will accept as an argument either the full Tinylink URL or just the
-Tinylink identifier/nickname.
-
-If anything goes wrong, then either function will return C<undef>.
-
-=cut
-
 sub makealongerlink ($)
 {
     my $code = shift
@@ -106,13 +61,47 @@ sub makealongerlink ($)
 
 __END__
 
+=head1 NAME
+
+WWW::Shorten::Tinylink - Perl interface to Tinylink.com
+
+=head1 SYNOPSIS
+
+  use WWW::Shorten 'Tinylink';
+
+  $short_url = makeashorterlink($long_url);
+
+  $long_url  = makealongerlink($short_url);
+  $long_url  = makealongerlink($nickname);
+
+=head1 DESCRIPTION
+
+A Perl interface to the web site Tinylink.com. Tinylink.com simply
+maintains a database of long URLs, each of which has a unique
+identifier.
+
+The function C<makeashorterlink> will call the Tinylink.com web site
+passing it your long URL and will return the shorter (tinylink) version.
+
+The function C<makealongerlink> does the reverse. C<makealongerlink>
+will accept as an argument either the full Tinylink URL or just the
+Tinylink identifier/nickname.
+
+If anything goes wrong, then either function will return C<undef>.
+
+Multiple submissions of the same URL will result in different codes
+being returned.
+
 =head2 EXPORT
 
 makeashorterlink, makealongerlink
 
-=head1 SUPPORT, LICENCE, THANKS and SUCH
+=head1 BUGS, REQUESTS, COMMENTS
 
-See the main L<WWW::Shorten> docs.
+Please report any requests, suggestions or bugs via the system at
+L<http://rt.cpan.org/>, or email E<lt>bug-WWW-Shorten@rt.cpan.orgE<gt>.
+This makes it much easier for me to track things and thus means
+your problem is less likely to be neglected.
 
 =head1 AUTHOR
 
